#---
#title: "ICLV Model"
#author: "Janak Parmar"
#date: "07/09/2021"
#output: html_document
#---

## Initialization

rm(list=ls())
library(apollo)
apollo_initialise()

## Set Core Controls

apollo_control= list(
  modelName= "ICLV",
  modelDescr= "Joint Mode and Parking Choice Model",
  indivID= "PID",
  mixing= TRUE,
  nCores= 5,
  analyticGrad= TRUE,
  HB= TRUE
)

## Load database

database= read.csv("iclvdata_v2.csv", header = T)

## Parameter operations

database$orgbus= database$orgbus / 100
database$orgmet= database$orgmet / 100
database$destbus= database$destbus / 100
database$destmet= database$destmet / 100
database$resdens= database$resdens / 1000
database$popdens= database$popdens / 1000
database$mtc_car= database$mtc_car / 1000
database$mtc_mtw= database$mtc_mtw / 1000
database$mtc_bus= database$mtc_bus / 1000
database$mtc_met= database$mtc_met / 1000
database$tt_bus= database$tt_bus / 10
database$tt_met= database$tt_met / 10
database$tt_car= database$tt_car / 10
database$tt_mtw= database$tt_mtw / 10
database$tt_nmt= database$tt_nmt / 10

## Definition of Model Parameters
### Vector of Parameters to be estimated

apollo_beta= c(# Alternate Specific Constants
               asc_caroff= 2.5,
               asc_caron= 2,
               asc_mtwoff= 2.5,
               asc_mtwon= 2.5,
               asc_bus= 0,
               asc_metro= -1,
               asc_nmt= 1,
               
               # Social-Economic parameters
               gamma_female= 0,
               gamma_age_under25= 0, gamma_age_2540= 0, gamma_age_above40= 0,
               gamma_education_grad= 0, gamma_education_nongrad= 0,
               gamma_pincome_20k= 0, gamma_pincome_20k35k= 0, gamma_pincome_35k50k= 0, gamma_pincome_50k70k= 0, gamma_pincome_70k= 0,
               gamma_workmem= 0,
               
               # Built-environment parameters
               b_orgbus_car=1, b_orgbus_mtw=2, b_orgbus_bus=-1, b_orgbus_metro=1, b_orgmet_car=1, b_orgmet_mtw=1, b_orgmet_bus=1, b_orgmet_metro=-1,
               b_destbus_car=0, b_destbus_mtw=1, b_destbus_bus=-1, b_destbus_metro=0.5, b_destmet_car=0.5, b_destmet_mtw=1.5, b_destmet_bus=1, b_destmet_metro=-1,
               b_entropy_car=-1, b_entropy_mtw=-1, b_entropy_bus=2, b_entropy_metro=1, b_entropy_nmt=1,
               b_resdens_car=-1, b_resdens_mtw=0, b_resdens_bus=1, b_resdens_metro=1, b_resdens_nmt=1,
               b_popdens_car=-1, b_popdens_mtw=0, b_popdens_bus=2, b_popdens_metro=1, b_popdens_nmt=2,
               
               # Trip attributes
               b_parkdur= 0,
               b_dist_car= 0, b_dist_mtw= 0, b_dist_bus= 0, b_dist_metro= 0, b_dist_nmt= 0,
               b_tt_car= -3, b_tt_mtw= -3, b_tt_bus= -3, b_tt_metro= -3, b_tt_nmt= -3,
               b_tc_car= -3, b_tc_mtw= -3, b_tc_bus= -3, b_tc_metro= -3,
               b_parkser_caroff= -3, b_parkser_caron= -3, b_parkser_mtwoff= -3, b_parkser_mtwon= -3,
               b_parkwalk_caroff= -3, b_parkwalk_caron= -3, b_parkwalk_mtwoff= -3, b_parkwalk_mtwon= -3,
               
               # Latent variables and thresholds in SEM component
               zeta_pv_individualist1= 1, zeta_pv_individualist2= 1, zeta_pv_individualist3= 1, zeta_pv_individualist4= 1,
               zeta_pv_proenv1= 1, zeta_pv_proenv2= 1, zeta_pv_proenv3= 1,
               zeta_pv_economy1=1, zeta_pv_economy2=1, zeta_pv_economy3=1,
               zeta_pv_comfort1= 1, zeta_pv_comfort2= 1,
               zeta_pv_flexibility1= 1, zeta_pv_flexibility2= 1, zeta_pv_flexibility3= 1,
               zeta_pt_comfort1= 1, zeta_pt_comfort2= 1, zeta_pt_comfort3= 1, zeta_pt_comfort4= 1,
               zeta_pt_convenience1= 1, zeta_pt_convenience2= 1, zeta_pt_convenience3= 1,
               zeta_pt_safety1= 1, zeta_pt_safety2= 1, zeta_pt_safety3= 1,
               zeta_pt_flexibility1= 1, zeta_pt_flexibility2= 1, zeta_pt_flexibility3= 1,
               zeta_nmt_health1= 1, zeta_nmt_health2= 1, zeta_nmt_health3= 1,
               zeta_nmt_comfort1= 1, zeta_nmt_comfort2= 1, 
               zeta_nmt_convenience1= 1, zeta_nmt_convenience2= 1, 
               zeta_nmt_safety1= 1, zeta_nmt_safety2= 1, zeta_nmt_safety3= 1,
               zeta_park_convenience1= 1, zeta_park_convenience2= 1, zeta_park_convenience3= 1,
               zeta_park_safety1= 1, zeta_park_safety2= 1,
               tau_pv_individualist1_1= -2, tau_pv_individualist1_2= -1, tau_pv_individualist1_3= 1,
               tau_pv_individualist2_1= -2, tau_pv_individualist2_2= -1, tau_pv_individualist2_3= 1, tau_pv_individualist2_4= 2,
               tau_pv_individualist3_1= -2, tau_pv_individualist3_2= -1, tau_pv_individualist3_3= 1, tau_pv_individualist3_4= 2,
               tau_pv_individualist4_1= -2, tau_pv_individualist4_2= -1, tau_pv_individualist4_3= 1,
               tau_pv_proenv1_1= -2, tau_pv_proenv1_2= -1, tau_pv_proenv1_3= 1, tau_pv_proenv1_4= 2,
               tau_pv_proenv2_1= -2, tau_pv_proenv2_2= -1, tau_pv_proenv2_3= 1, tau_pv_proenv2_4= 2,
               tau_pv_proenv3_1= -2, tau_pv_proenv3_2= -1, tau_pv_proenv3_3= 1,
               tau_pv_economy1_1= -2, tau_pv_economy1_2= -1, tau_pv_economy1_3= 1, tau_pv_economy1_4= 2,
               tau_pv_economy2_1= -2, tau_pv_economy2_2= -1, tau_pv_economy2_3= 1, tau_pv_economy2_4= 2,
               tau_pv_economy3_1= -2, tau_pv_economy3_2= -1, tau_pv_economy3_3= 1, tau_pv_economy3_4= 2,
               tau_pv_comfort1_1= -2, tau_pv_comfort1_2= -1, tau_pv_comfort1_3= 1, tau_pv_comfort1_4= 2,
               tau_pv_comfort2_1= -2, tau_pv_comfort2_2= -1, tau_pv_comfort2_3= 1, tau_pv_comfort2_4= 2,
               tau_pv_flexibility1_1= -2, tau_pv_flexibility1_2= -1,
               tau_pv_flexibility2_1= -2, tau_pv_flexibility2_2= -1, tau_pv_flexibility2_3= 1, tau_pv_flexibility2_4= 2,
               tau_pv_flexibility3_1= -2, tau_pv_flexibility3_2= -1, tau_pv_flexibility3_3= 1, tau_pv_flexibility3_4= 2,
               tau_pt_comfort1_1= -2, tau_pt_comfort1_2= -1, tau_pt_comfort1_3= 1, tau_pt_comfort1_4= 2,
               tau_pt_comfort2_1= -2, tau_pt_comfort2_2= -1, tau_pt_comfort2_3= 1, tau_pt_comfort2_4= 2,
               tau_pt_comfort3_1= -2, tau_pt_comfort3_2= -1, tau_pt_comfort3_3= 1,
               tau_pt_comfort4_1= -2, tau_pt_comfort4_2= -1, tau_pt_comfort4_3= 1, tau_pt_comfort4_4= 2,
               tau_pt_convenience1_1= -2, tau_pt_convenience1_2= -1, tau_pt_convenience1_3= 1, tau_pt_convenience1_4= 2,
               tau_pt_convenience2_1= -2, tau_pt_convenience2_2= -1, tau_pt_convenience2_3= 1, tau_pt_convenience2_4= 2,
               tau_pt_convenience3_1= -2, tau_pt_convenience3_2= -1, tau_pt_convenience3_3= 1, tau_pt_convenience3_4= 2,
               tau_pt_safety1_1= -2, tau_pt_safety1_2= -1, tau_pt_safety1_3= 1, tau_pt_safety1_4= 2,
               tau_pt_safety2_1= -2, tau_pt_safety2_2= -1, tau_pt_safety2_3= 1, tau_pt_safety2_4= 2,
               tau_pt_safety3_1= -2, tau_pt_safety3_2= -1, tau_pt_safety3_3= 1, tau_pt_safety3_4= 2,
               tau_pt_flexibility1_1= -2, tau_pt_flexibility1_2= -1, tau_pt_flexibility1_3= 1, tau_pt_flexibility1_4= 2,
               tau_pt_flexibility2_1= -2, tau_pt_flexibility2_2= -1, tau_pt_flexibility2_3= 1, tau_pt_flexibility2_4= 2,
               tau_pt_flexibility3_1= -2, tau_pt_flexibility3_2= -1, tau_pt_flexibility3_3= 1, tau_pt_flexibility3_4= 2,
               tau_nmt_health1_1= -2, tau_nmt_health1_2= -1, tau_nmt_health1_3= 1,
               tau_nmt_health2_1= -2, tau_nmt_health2_2= -1, tau_nmt_health2_3= 1, tau_nmt_health2_4= 2,
               tau_nmt_health3_1= -2, tau_nmt_health3_2= -1, tau_nmt_health3_3= 1, tau_nmt_health3_4= 2,
               tau_nmt_comfort1_1= -2, tau_nmt_comfort1_2= -1, tau_nmt_comfort1_3= 1,
               tau_nmt_comfort2_1= -2, tau_nmt_comfort2_2= -1, tau_nmt_comfort2_3= 1,
               tau_nmt_convenience1_1= -2, tau_nmt_convenience1_2= -1, tau_nmt_convenience1_3= 1,
               tau_nmt_convenience2_1= -1, tau_nmt_convenience2_2= 1,
               tau_nmt_safety1_1= -2, tau_nmt_safety1_2= -1,
               tau_nmt_safety2_1= -2, tau_nmt_safety2_2= -1, tau_nmt_safety2_3= 1,
               tau_nmt_safety3_1= -2, tau_nmt_safety3_2= -1, tau_nmt_safety3_3= 1,
               tau_park_convenience1_1= -2, tau_park_convenience1_2= -1, tau_park_convenience1_3= 1, tau_park_convenience1_4= 1,
               tau_park_convenience2_1= -2, tau_park_convenience2_2= -1, tau_park_convenience2_3= 1,
               tau_park_convenience3_1= -2, tau_park_convenience3_2= -1, tau_park_convenience3_3= 1, tau_park_convenience3_4= 2,
               tau_park_safety1_1= -2, tau_park_safety1_2= -1, tau_park_safety1_3= 1, tau_park_safety1_4= 2,
               tau_park_safety2_1= -2, tau_park_safety2_2= -1, tau_park_safety2_3= 1,
               
               # Latent variables in choice model component
               lambda_pv_individualist_car=1, lambda_pv_individualist_mtw=2,
               lambda_pv_proenv_car=-1, lambda_pv_proenv_mtw=-1,
               lambda_pv_economy_car=1, lambda_pv_economy_mtw=2,
               lambda_pv_comfort_car=1, lambda_pv_comfort_mtw=1,
               lambda_pv_flexibility_car=1, lambda_pv_flexibility_mtw=2,
               lambda_pt_comfort_car=-1, lambda_pt_comfort_mtw=-1, lambda_pt_comfort_bus=1, lambda_pt_comfort_metro=2, lambda_pt_comfort_nmt=0,
               lambda_pt_convenience_car=-1, lambda_pt_convenience_mtw=-1, lambda_pt_convenience_bus=1, lambda_pt_convenience_metro=1.5, lambda_pt_convenience_nmt=-1,
               lambda_pt_safety_car=-2, lambda_pt_safety_mtw=-2, lambda_pt_safety_bus=2, lambda_pt_safety_metro=1, lambda_pt_safety_nmt=0,
               lambda_pt_flexibility_car=-1, lambda_pt_flexibility_mtw=-1, lambda_pt_flexibility_bus=1, lambda_pt_flexibility_metro=1, lambda_pt_flexibility_nmt=0,
               lambda_nmt_health_car=-1, lambda_nmt_health_mtw=-1, lambda_nmt_health_bus=-1, lambda_nmt_health_metro=-1, lambda_nmt_health_nmt=1,
               lambda_nmt_safety_car=-1, lambda_nmt_safety_mtw=-1, lambda_nmt_safety_bus=-1, lambda_nmt_safety_metro=-1, lambda_nmt_safety_nmt=2,
               lambda_nmt_comfort_car=0, lambda_nmt_comfort_mtw=0, lambda_nmt_comfort_bus=0, lambda_nmt_comfort_metro=0, lambda_nmt_comfort_nmt=1,
               lambda_nmt_convenience_car=-1, lambda_nmt_convenience_mtw=0, lambda_nmt_convenience_bus=0, lambda_nmt_convenience_metro=-1, lambda_nmt_convenience_nmt=1,
               lambda_park_safety_caroff=1, lambda_park_safety_caron=1, lambda_park_safety_mtwoff=1, lambda_park_safety_mtwon=1,
               lambda_park_convenience_caroff=1, lambda_park_convenience_caron=1, lambda_park_convenience_mtwoff=1, lambda_park_convenience_mtwon=1,
               
               # ETA
               eta1= 0, eta2= 0, eta3= 0, eta4= 0, eta5= 0, eta6= 0, eta7= 0, eta8= 0, eta9= 0, eta10= 0, eta11= 0, eta12= 0, eta13= 0, eta14= 0, eta15= 0
               )

## Parameters to be kept FIXED

apollo_fixed= c("asc_bus", 'gamma_age_under25', 'gamma_education_nongrad', 'gamma_pincome_20k','zeta_pv_individualist1','zeta_pv_proenv1','zeta_pv_economy1','zeta_pv_flexibility1',
                'zeta_pt_comfort1','zeta_pt_safety1','zeta_pt_convenience1','zeta_pt_flexibility1','zeta_nmt_safety1','zeta_nmt_comfort1','zeta_nmt_convenience1','zeta_nmt_health1',
                'zeta_park_safety1','zeta_park_convenience1')

## HB Settings

apollo_HB= list(
  hbDist= c(
    # Alternate Specific Constants
    asc_caroff= "N",
    asc_caron= "N",
    asc_mtwoff= "N",
    asc_mtwon= "N",
    asc_bus= "F",
    asc_metro= "N",
    asc_nmt= "N",
    
    # Social-Economic parameters
    gamma_female= "F",
    gamma_age_under25= "F", gamma_age_2540= "F", gamma_age_above40= "F",
    gamma_education_grad= "F", gamma_education_nongrad= "F",
    gamma_pincome_20k= "F", gamma_pincome_20k35k= "F", gamma_pincome_35k50k= "F", gamma_pincome_50k70k= "F", gamma_pincome_70k= "F",
    gamma_workmem= "F",
    
    # Built-environment parameters
    b_orgbus_car="F", b_orgbus_mtw="F", b_orgbus_bus="F", b_orgbus_metro="F", b_orgmet_car="F", b_orgmet_mtw="F", b_orgmet_bus="F", b_orgmet_metro="F",
    b_destbus_car="F", b_destbus_mtw="F", b_destbus_bus="F", b_destbus_metro="F", b_destmet_car="F", b_destmet_mtw="F", b_destmet_bus="F", b_destmet_metro="F",
    b_entropy_car="F", b_entropy_mtw="F", b_entropy_bus="F", b_entropy_metro="F", b_entropy_nmt="F",
    b_resdens_car="F", b_resdens_mtw="F", b_resdens_bus="F", b_resdens_metro="F", b_resdens_nmt="F",
    b_popdens_car="F", b_popdens_mtw="F", b_popdens_bus="F", b_popdens_metro="F", b_popdens_nmt="F",
    
    # Trip attributes
    b_parkdur= "N",
    b_dist_car= "F", b_dist_mtw= "F", b_dist_bus= "F", b_dist_metro= "F", b_dist_nmt= "F",
    b_tt_car= "N", b_tt_mtw= "N", b_tt_bus= "N", b_tt_metro= "N", b_tt_nmt= "N",
    b_tc_car= "N", b_tc_mtw= "N", b_tc_bus= "N", b_tc_metro= "N",
    b_parkser_caroff= "N", b_parkser_caron= "N", b_parkser_mtwoff= "N", b_parkser_mtwon= "N",
    b_parkwalk_caroff= "N", b_parkwalk_caron= "N", b_parkwalk_mtwoff= "N", b_parkwalk_mtwon= "N",
    
    # Latent variables and thresholds in SEM component
    zeta_pv_individualist1= "F", zeta_pv_individualist2= "F", zeta_pv_individualist3= "F", zeta_pv_individualist4= "F",
    zeta_pv_proenv1= "F", zeta_pv_proenv2= "F", zeta_pv_proenv3= "F",
    zeta_pv_economy1= "F", zeta_pv_economy2= "F", zeta_pv_economy3= "F",
    zeta_pv_comfort1= "F", zeta_pv_comfort2= "F",
    zeta_pv_flexibility1= "F", zeta_pv_flexibility2= "F", zeta_pv_flexibility3= "F",
    zeta_pt_comfort1= "F", zeta_pt_comfort2= "F", zeta_pt_comfort3= "F", zeta_pt_comfort4= "F",
    zeta_pt_convenience1= "F", zeta_pt_convenience2= "F", zeta_pt_convenience3= "F",
    zeta_pt_safety1= "F", zeta_pt_safety2= "F", zeta_pt_safety3= "F",
    zeta_pt_flexibility1= "F", zeta_pt_flexibility2= "F", zeta_pt_flexibility3= "F",
    zeta_nmt_health1= "F", zeta_nmt_health2= "F", zeta_nmt_health3= "F",
    zeta_nmt_comfort1= "F", zeta_nmt_comfort2= "F", 
    zeta_nmt_convenience1= "F", zeta_nmt_convenience2= "F", 
    zeta_nmt_safety1= "F", zeta_nmt_safety2= "F", zeta_nmt_safety3= "F",
    zeta_park_convenience1= "F", zeta_park_convenience2= "F", zeta_park_convenience3= "F",
    zeta_park_safety1= "F", zeta_park_safety2= "F",
    tau_pv_individualist1_1= "F", tau_pv_individualist1_2= "F", tau_pv_individualist1_3= "F",
    tau_pv_individualist2_1= "F", tau_pv_individualist2_2= "F", tau_pv_individualist2_3= "F", tau_pv_individualist2_4= "F",
    tau_pv_individualist3_1= "F", tau_pv_individualist3_2= "F", tau_pv_individualist3_3= "F", tau_pv_individualist3_4= "F",
    tau_pv_individualist4_1= "F", tau_pv_individualist4_2= "F", tau_pv_individualist4_3= "F",
    tau_pv_proenv1_1= "F", tau_pv_proenv1_2= "F", tau_pv_proenv1_3= "F", tau_pv_proenv1_4= "F",
    tau_pv_proenv2_1= "F", tau_pv_proenv2_2= "F", tau_pv_proenv2_3= "F", tau_pv_proenv2_4= "F",
    tau_pv_proenv3_1= "F", tau_pv_proenv3_2= "F", tau_pv_proenv3_3= "F",
    tau_pv_economy1_1= "F", tau_pv_economy1_2= "F", tau_pv_economy1_3= "F", tau_pv_economy1_4= "F",
    tau_pv_economy2_1= "F", tau_pv_economy2_2= "F", tau_pv_economy2_3= "F", tau_pv_economy2_4= "F",
    tau_pv_economy3_1= "F", tau_pv_economy3_2= "F", tau_pv_economy3_3= "F", tau_pv_economy3_4= "F",
    tau_pv_comfort1_1= "F", tau_pv_comfort1_2= "F", tau_pv_comfort1_3= "F", tau_pv_comfort1_4= "F",
    tau_pv_comfort2_1= "F", tau_pv_comfort2_2= "F", tau_pv_comfort2_3= "F", tau_pv_comfort2_4= "F",
    tau_pv_flexibility1_1= "F", tau_pv_flexibility1_2= "F",
    tau_pv_flexibility2_1= "F", tau_pv_flexibility2_2= "F", tau_pv_flexibility2_3= "F", tau_pv_flexibility2_4= "F",
    tau_pv_flexibility3_1= "F", tau_pv_flexibility3_2= "F", tau_pv_flexibility3_3= "F", tau_pv_flexibility3_4= "F",
    tau_pt_comfort1_1= "F", tau_pt_comfort1_2= "F", tau_pt_comfort1_3= "F", tau_pt_comfort1_4= "F",
    tau_pt_comfort2_1= "F", tau_pt_comfort2_2= "F", tau_pt_comfort2_3= "F", tau_pt_comfort2_4= "F",
    tau_pt_comfort3_1= "F", tau_pt_comfort3_2= "F", tau_pt_comfort3_3= "F",
    tau_pt_comfort4_1= "F", tau_pt_comfort4_2= "F", tau_pt_comfort4_3= "F", tau_pt_comfort4_4= "F",
    tau_pt_convenience1_1= "F", tau_pt_convenience1_2= "F", tau_pt_convenience1_3= "F", tau_pt_convenience1_4= "F",
    tau_pt_convenience2_1= "F", tau_pt_convenience2_2= "F", tau_pt_convenience2_3= "F", tau_pt_convenience2_4= "F",
    tau_pt_convenience3_1= "F", tau_pt_convenience3_2= "F", tau_pt_convenience3_3= "F", tau_pt_convenience3_4= "F",
    tau_pt_safety1_1= "F", tau_pt_safety1_2= "F", tau_pt_safety1_3= "F", tau_pt_safety1_4= "F",
    tau_pt_safety2_1= "F", tau_pt_safety2_2= "F", tau_pt_safety2_3= "F", tau_pt_safety2_4= "F",
    tau_pt_safety3_1= "F", tau_pt_safety3_2= "F", tau_pt_safety3_3= "F", tau_pt_safety3_4= "F",
    tau_pt_flexibility1_1= "F", tau_pt_flexibility1_2= "F", tau_pt_flexibility1_3= "F", tau_pt_flexibility1_4= "F",
    tau_pt_flexibility2_1= "F", tau_pt_flexibility2_2= "F", tau_pt_flexibility2_3= "F", tau_pt_flexibility2_4= "F",
    tau_pt_flexibility3_1= "F", tau_pt_flexibility3_2= "F", tau_pt_flexibility3_3= "F", tau_pt_flexibility3_4= "F",
    tau_nmt_health1_1= "F", tau_nmt_health1_2= "F", tau_nmt_health1_3= "F",
    tau_nmt_health2_1= "F", tau_nmt_health2_2= "F", tau_nmt_health2_3= "F", tau_nmt_health2_4= "F",
    tau_nmt_health3_1= "F", tau_nmt_health3_2= "F", tau_nmt_health3_3= "F", tau_nmt_health3_4= "F",
    tau_nmt_comfort1_1= "F", tau_nmt_comfort1_2= "F", tau_nmt_comfort1_3= "F",
    tau_nmt_comfort2_1= "F", tau_nmt_comfort2_2= "F", tau_nmt_comfort2_3= "F",
    tau_nmt_convenience1_1= "F", tau_nmt_convenience1_2= "F", tau_nmt_convenience1_3= "F",
    tau_nmt_convenience2_1= "F", tau_nmt_convenience2_2= "F",
    tau_nmt_safety1_1= "F", tau_nmt_safety1_2= "F",
    tau_nmt_safety2_1= "F", tau_nmt_safety2_2= "F", tau_nmt_safety2_3= "F",
    tau_nmt_safety3_1= "F", tau_nmt_safety3_2= "F", tau_nmt_safety3_3= "F",
    tau_park_convenience1_1= "F", tau_park_convenience1_2= "F", tau_park_convenience1_3= "F", tau_park_convenience1_4= "F",
    tau_park_convenience2_1= "F", tau_park_convenience2_2= "F", tau_park_convenience2_3= "F",
    tau_park_convenience3_1= "F", tau_park_convenience3_2= "F", tau_park_convenience3_3= "F", tau_park_convenience3_4= "F",
    tau_park_safety1_1= "F", tau_park_safety1_2= "F", tau_park_safety1_3= "F", tau_park_safety1_4= "F",
    tau_park_safety2_1= "F", tau_park_safety2_2= "F", tau_park_safety2_3= "F",
    
    # Latent variables in choice model component
    lambda_pv_individualist_car="F", lambda_pv_individualist_mtw="F",
    lambda_pv_proenv_car="F", lambda_pv_proenv_mtw="F",
    lambda_pv_economy_car="F", lambda_pv_economy_mtw="F",
    lambda_pv_comfort_car="F", lambda_pv_comfort_mtw="F",
    lambda_pv_flexibility_car="F", lambda_pv_flexibility_mtw="F",
    lambda_pt_comfort_car="F", lambda_pt_comfort_mtw="F", lambda_pt_comfort_bus="F", lambda_pt_comfort_metro="F", lambda_pt_comfort_nmt="F",
    lambda_pt_convenience_car="F", lambda_pt_convenience_mtw="F", lambda_pt_convenience_bus="F", lambda_pt_convenience_metro="F", lambda_pt_convenience_nmt="F",
    lambda_pt_safety_car="F", lambda_pt_safety_mtw="F", lambda_pt_safety_bus="F", lambda_pt_safety_metro="F", lambda_pt_safety_nmt="F",
    lambda_pt_flexibility_car="F", lambda_pt_flexibility_mtw="F", lambda_pt_flexibility_bus="F", lambda_pt_flexibility_metro="F", lambda_pt_flexibility_nmt="F",
    lambda_nmt_health_car="F", lambda_nmt_health_mtw="F", lambda_nmt_health_bus="F", lambda_nmt_health_metro="F", lambda_nmt_health_nmt="F",
    lambda_nmt_safety_car="F", lambda_nmt_safety_mtw="F", lambda_nmt_safety_bus="F", lambda_nmt_safety_metro="F", lambda_nmt_safety_nmt="F",
    lambda_nmt_comfort_car="F", lambda_nmt_comfort_mtw="F", lambda_nmt_comfort_bus="F", lambda_nmt_comfort_metro="F", lambda_nmt_comfort_nmt="F",
    lambda_nmt_convenience_car="F", lambda_nmt_convenience_mtw="F", lambda_nmt_convenience_bus="F", lambda_nmt_convenience_metro="F", lambda_nmt_convenience_nmt="F",
    lambda_park_safety_caroff="F", lambda_park_safety_caron="F", lambda_park_safety_mtwoff="F", lambda_park_safety_mtwon="F",
    lambda_park_convenience_caroff="F", lambda_park_convenience_caron="F", lambda_park_convenience_mtwoff="F", lambda_park_convenience_mtwon="F",
    
    # ETA
    eta1= "N", eta2= "N", eta3= "N", eta4= "N", eta5= "N", eta6= "N", eta7= "N", eta8= "N", eta9= "N", eta10= "N", eta11= "N", eta12= "N", eta13= "N", eta14= "N", eta15= "N"),
  gNCREP= 100000,
  GNEREP= 100000,
  gINFOSKIP= 500,
  gFULLCV= FALSE
)

## Group and Validate Inputs

apollo_inputs= apollo_validateInputs()

## Model Definition and Likelihood Function

apollo_probabilities= function(apollo_beta, apollo_inputs, functionality= "estimate"){
  
  # Attach inputs and detach after function exit
  
  apollo_attach(apollo_beta, apollo_inputs)
  on.exit(apollo_detach(apollo_beta, apollo_inputs))
  
  # Create Random LVs
  
  pv_individualist= gamma_female*female + gamma_age_2540*(age==2) + gamma_age_above40*(age==3) + gamma_education_grad*education +
    gamma_pincome_20k35k*(pincome==2) + gamma_pincome_35k50k*(pincome==3) + gamma_pincome_50k70k*(pincome==4) + gamma_pincome_70k*(pincome==5) + eta1 
  
  pv_proenv= gamma_female*female + gamma_age_2540*(age==2) + gamma_age_above40*(age==3) + gamma_education_grad*education +
    gamma_pincome_20k35k*(pincome==2) + gamma_pincome_35k50k*(pincome==3) + gamma_pincome_50k70k*(pincome==4) + gamma_pincome_70k*(pincome==5) + eta2 
  
  pv_comfort= gamma_female*female + gamma_age_2540*(age==2) + gamma_age_above40*(age==3) + gamma_education_grad*education +
    gamma_pincome_20k35k*(pincome==2) + gamma_pincome_35k50k*(pincome==3) + gamma_pincome_50k70k*(pincome==4) + gamma_pincome_70k*(pincome==5) + eta3 
  
  pv_economy= gamma_female*female + gamma_age_2540*(age==2) + gamma_age_above40*(age==3) + gamma_education_grad*education +
    gamma_pincome_20k35k*(pincome==2) + gamma_pincome_35k50k*(pincome==3) + gamma_pincome_50k70k*(pincome==4) + gamma_pincome_70k*(pincome==5) + gamma_workmem*workmem + eta4
  
  pv_flexibility= gamma_female*female + gamma_age_2540*(age==2) + gamma_age_above40*(age==3) + gamma_education_grad*education +
    gamma_pincome_20k35k*(pincome==2) + gamma_pincome_35k50k*(pincome==3) + gamma_pincome_50k70k*(pincome==4) + gamma_pincome_70k*(pincome==5) + eta5
  
  pt_comfort= gamma_female*female + gamma_age_2540*(age==2) + gamma_age_above40*(age==3) + gamma_education_grad*education +
    gamma_pincome_20k35k*(pincome==2) + gamma_pincome_35k50k*(pincome==3) + gamma_pincome_50k70k*(pincome==4) + gamma_pincome_70k*(pincome==5) + eta6
  
  pt_convenience= gamma_female*female + gamma_age_2540*(age==2) + gamma_age_above40*(age==3) + gamma_education_grad*education +
    gamma_pincome_20k35k*(pincome==2) + gamma_pincome_35k50k*(pincome==3) + gamma_pincome_50k70k*(pincome==4) + gamma_pincome_70k*(pincome==5) + eta7
  
  pt_safety= gamma_female*female + gamma_age_2540*(age==2) + gamma_age_above40*(age==3) + gamma_education_grad*education +
    gamma_pincome_20k35k*(pincome==2) + gamma_pincome_35k50k*(pincome==3) + gamma_pincome_50k70k*(pincome==4) + gamma_pincome_70k*(pincome==5) + eta8
  
  pt_flexibility= gamma_female*female + gamma_age_2540*(age==2) + gamma_age_above40*(age==3) + gamma_education_grad*education +
    gamma_pincome_20k35k*(pincome==2) + gamma_pincome_35k50k*(pincome==3) + gamma_pincome_50k70k*(pincome==4) + gamma_pincome_70k*(pincome==5) + eta9
  
  nmt_health= gamma_female*female + gamma_age_2540*(age==2) + gamma_age_above40*(age==3) + gamma_education_grad*education +
    gamma_pincome_20k35k*(pincome==2) + gamma_pincome_35k50k*(pincome==3) + gamma_pincome_50k70k*(pincome==4) + gamma_pincome_70k*(pincome==5) + eta10
  
  nmt_comfort= gamma_female*female + gamma_age_2540*(age==2) + gamma_age_above40*(age==3) + gamma_education_grad*education +
    gamma_pincome_20k35k*(pincome==2) + gamma_pincome_35k50k*(pincome==3) + gamma_pincome_50k70k*(pincome==4) + gamma_pincome_70k*(pincome==5) + eta11
  
  nmt_safety= gamma_female*female + gamma_age_2540*(age==2) + gamma_age_above40*(age==3) + gamma_education_grad*education +
    gamma_pincome_20k35k*(pincome==2) + gamma_pincome_35k50k*(pincome==3) + gamma_pincome_50k70k*(pincome==4) + gamma_pincome_70k*(pincome==5) + eta12
  
  nmt_convenience= gamma_female*female + gamma_age_2540*(age==2) + gamma_age_above40*(age==3) + gamma_education_grad*education +
    gamma_pincome_20k35k*(pincome==2) + gamma_pincome_35k50k*(pincome==3) + gamma_pincome_50k70k*(pincome==4) + gamma_pincome_70k*(pincome==5) + eta13
  
  park_safety= gamma_female*female + gamma_age_2540*(age==2) + gamma_age_above40*(age==3) + gamma_education_grad*education + eta14
  
  park_convenience= gamma_female*female + gamma_age_2540*(age==2) + gamma_age_above40*(age==3) + gamma_education_grad*education + eta15
  
  # Creating list of probabilities P
  
  P= list()
  
  ## Likelihood of Choices
  ## List of utilities 
  
  V= list()
  V[['caroff']]= (asc_caroff +  b_orgbus_car*orgbus + b_destbus_car*destbus + b_orgmet_car*orgmet + b_destmet_car*destmet + b_entropy_car*entropy + b_resdens_car*resdens + b_popdens_car*popdens +
                    b_parkdur*parkdur + b_dist_car*dist + b_tt_car*tt_car + b_tc_car*mtc_car + b_parkser_caroff*ser_caroff + b_parkwalk_caroff*wak_caroff + 
                    lambda_pv_individualist_car*pv_individualist + lambda_pv_proenv_car*pv_proenv + lambda_pv_comfort_car*pv_comfort + lambda_pv_flexibility_car*pv_flexibility +
                    lambda_pv_economy_car*pv_economy +
                    lambda_pt_comfort_car*pt_comfort + lambda_pt_convenience_car*pt_convenience + lambda_pt_safety_car*pt_safety + lambda_pt_flexibility_car*pt_flexibility +
                    lambda_nmt_health_car*nmt_health + lambda_nmt_safety_car*nmt_safety + lambda_nmt_convenience_car*nmt_convenience + lambda_nmt_comfort_car*nmt_comfort + 
                    lambda_park_safety_caroff*park_safety + lambda_park_convenience_caroff*park_convenience)
  
  V[['caron']]= (asc_caron +  b_orgbus_car*orgbus + b_destbus_car*destbus + b_orgmet_car*orgmet + b_destmet_car*destmet + b_entropy_car*entropy + b_resdens_car*resdens + b_popdens_car*popdens +
                   b_parkdur*parkdur + b_dist_car*dist + b_tt_car*tt_car + b_tc_car*mtc_car + b_parkser_caron*ser_caron + b_parkwalk_caron*wak_caron + 
                   lambda_pv_individualist_car*pv_individualist + lambda_pv_proenv_car*pv_proenv + lambda_pv_comfort_car*pv_comfort + lambda_pv_flexibility_car*pv_flexibility +
                   lambda_pv_economy_car*pv_economy +
                   lambda_pt_comfort_car*pt_comfort + lambda_pt_convenience_car*pt_convenience + lambda_pt_safety_car*pt_safety + lambda_pt_flexibility_car*pt_flexibility +
                   lambda_nmt_health_car*nmt_health + lambda_nmt_safety_car*nmt_safety + lambda_nmt_convenience_car*nmt_convenience + lambda_nmt_comfort_car*nmt_comfort + 
                   lambda_park_safety_caron*park_safety + lambda_park_convenience_caron*park_convenience)
  
  V[['mtwoff']]= (asc_mtwoff + b_orgbus_mtw*orgbus + b_destbus_mtw*destbus + b_orgmet_mtw*orgmet + b_destmet_mtw*destmet + b_entropy_mtw*entropy + b_resdens_mtw*resdens + b_popdens_mtw*popdens +
                    b_parkdur*parkdur + b_dist_mtw*dist + b_tt_mtw*tt_mtw + b_tc_mtw*mtc_mtw + b_parkser_mtwoff*ser_mtwoff + b_parkwalk_mtwoff*wak_mtwoff +
                    lambda_pv_economy_mtw*pv_economy +
                    lambda_pv_individualist_mtw*pv_individualist + lambda_pv_proenv_mtw*pv_proenv + lambda_pv_comfort_mtw*pv_comfort + lambda_pv_flexibility_mtw*pv_flexibility +
                    lambda_pt_comfort_mtw*pt_comfort + lambda_pt_convenience_mtw*pt_convenience + lambda_pt_safety_mtw*pt_safety + lambda_pt_flexibility_mtw*pt_flexibility +
                    lambda_nmt_health_mtw*nmt_health + lambda_nmt_safety_mtw*nmt_safety + lambda_nmt_convenience_mtw*nmt_convenience + lambda_nmt_comfort_mtw*nmt_comfort + 
                    lambda_park_safety_mtwoff*park_safety + lambda_park_convenience_mtwoff*park_convenience)
  
  V[['mtwon']]= (asc_mtwon + b_orgbus_mtw*orgbus + b_destbus_mtw*destbus + b_orgmet_mtw*orgmet + b_destmet_mtw*destmet + b_entropy_mtw*entropy + b_resdens_mtw*resdens + b_popdens_mtw*popdens +
                   b_parkdur*parkdur + b_dist_mtw*dist + b_tt_mtw*tt_mtw + b_tc_mtw*mtc_mtw + b_parkser_mtwon*ser_mtwon + b_parkwalk_mtwon*wak_mtwon +
                   lambda_pv_economy_mtw*pv_economy +
                   lambda_pv_individualist_mtw*pv_individualist + lambda_pv_proenv_mtw*pv_proenv + lambda_pv_comfort_mtw*pv_comfort + lambda_pv_flexibility_mtw*pv_flexibility +
                   lambda_pt_comfort_mtw*pt_comfort + lambda_pt_convenience_mtw*pt_convenience + lambda_pt_safety_mtw*pt_safety + lambda_pt_flexibility_mtw*pt_flexibility +
                   lambda_nmt_health_mtw*nmt_health + lambda_nmt_safety_mtw*nmt_safety + lambda_nmt_convenience_mtw*nmt_convenience + lambda_nmt_comfort_mtw*nmt_comfort + 
                   lambda_park_safety_mtwon*park_safety + lambda_park_convenience_mtwon*park_convenience)
  
  V[['bus']]= (asc_bus + b_orgbus_bus*orgbus + b_destbus_bus*destbus + b_orgmet_bus*orgmet + b_destmet_bus*destmet + b_entropy_bus*entropy + b_resdens_bus*resdens + b_popdens_bus*popdens +
                 b_dist_bus*dist + b_tt_bus*tt_bus + b_tc_bus*mtc_bus +
                 lambda_pt_comfort_bus*pt_comfort + lambda_pt_convenience_bus*pt_convenience + lambda_pt_safety_bus*pt_safety + lambda_pt_flexibility_bus*pt_flexibility +
                 lambda_nmt_health_bus*nmt_health + lambda_nmt_safety_bus*nmt_safety + lambda_nmt_convenience_bus*nmt_convenience + lambda_nmt_comfort_bus*nmt_comfort)
  
  V[['metro']]= (asc_metro + b_orgbus_metro*orgbus + b_destbus_metro*destbus + b_orgmet_metro*orgmet + b_destmet_metro*destmet + b_entropy_metro*entropy + b_resdens_metro*resdens + 
                   b_popdens_metro*popdens +
                   b_dist_metro*dist + b_tt_metro*tt_met + b_tc_metro*mtc_met +
                   lambda_pt_comfort_metro*pt_comfort + lambda_pt_convenience_metro*pt_convenience + lambda_pt_safety_metro*pt_safety + lambda_pt_flexibility_metro*pt_flexibility +
                   lambda_nmt_health_metro*nmt_health + lambda_nmt_safety_metro*nmt_safety + lambda_nmt_convenience_metro*nmt_convenience + lambda_nmt_comfort_metro*nmt_comfort)
  
  V[['nmt']]= (asc_nmt + b_entropy_nmt*entropy + b_resdens_nmt*resdens + b_popdens_nmt*popdens +
                 b_dist_nmt*dist + b_tt_nmt*tt_nmt +
                 lambda_pt_comfort_nmt*pt_comfort + lambda_pt_convenience_nmt*pt_convenience + lambda_pt_safety_nmt*pt_safety + lambda_pt_flexibility_nmt*pt_flexibility +
                 lambda_nmt_health_nmt*nmt_health + lambda_nmt_safety_nmt*nmt_safety + lambda_nmt_convenience_nmt*nmt_convenience + lambda_nmt_comfort_nmt*nmt_comfort)
  
  ## Settings for MNL model component
  
  mnl_settings= list(
    alternatives= c(caroff=1, caron=2, mtwoff=3, mtwon=4, bus=5, metro=6, nmt=7),
    avail= list(caroff=av_caroff, caron=av_caron, mtwoff=av_mtwoff, mtwon=av_mtwon, bus=av_bus, metro=av_met, nmt=av_nmt),
    choiceVar= mode,
    V= V
  )
  
  ## Computing probabilities for MNL model component
  
  P[["choice"]]= apollo_mnl(mnl_settings, functionality)
  
  # Likelihood of indicators to the LVs
  
  ol_settings1= list(outcomeOrdered= pv_individualist1,
                     V= zeta_pv_individualist1*pv_individualist,
                     tau= list(tau_pv_individualist1_1, tau_pv_individualist1_2, tau_pv_individualist1_3),
                     rows=pv_individualist1!=0)
  ol_settings2= list(outcomeOrdered= pv_individualist2,
                     V= zeta_pv_individualist2*pv_individualist,
                     tau= list(tau_pv_individualist2_1, tau_pv_individualist2_2, tau_pv_individualist2_3, tau_pv_individualist2_4),
                     rows=pv_individualist2!=0)
  ol_settings3= list(outcomeOrdered= pv_individualist3,
                     V= zeta_pv_individualist3*pv_individualist,
                     tau= list(tau_pv_individualist3_1, tau_pv_individualist3_2, tau_pv_individualist3_3, tau_pv_individualist3_4),
                     rows=pv_individualist3!=0)
  ol_settings4= list(outcomeOrdered= pv_individualist4,
                     V= zeta_pv_individualist4*pv_individualist,
                     tau= list(tau_pv_individualist4_1, tau_pv_individualist4_2, tau_pv_individualist4_3),
                     rows=pv_individualist4!=0)
  ol_settings5= list(outcomeOrdered= pv_proenv1,
                     V= zeta_pv_proenv1*pv_proenv,
                     tau= list(tau_pv_proenv1_1, tau_pv_proenv1_2, tau_pv_proenv1_3, tau_pv_proenv1_4),
                     rows=pv_proenv1!=0)
  ol_settings6= list(outcomeOrdered= pv_proenv2,
                     V= zeta_pv_proenv2*pv_proenv,
                     tau= list(tau_pv_proenv2_1, tau_pv_proenv2_2, tau_pv_proenv2_3, tau_pv_proenv2_4),
                     rows=pv_proenv2!=0)
  ol_settings7= list(outcomeOrdered= pv_proenv3,
                     V= zeta_pv_proenv3*pv_proenv,
                     tau= list(tau_pv_proenv3_1, tau_pv_proenv3_2, tau_pv_proenv3_3),
                     rows=pv_proenv3!=0)
  ol_settings8= list(outcomeOrdered= pv_comfort1,
                     V= zeta_pv_comfort1*pv_comfort,
                     tau= list(tau_pv_comfort1_1, tau_pv_comfort1_2, tau_pv_comfort1_3, tau_pv_comfort1_4),
                     rows=pv_comfort1!=0)
  ol_settings9= list(outcomeOrdered= pv_comfort2,
                     V= zeta_pv_comfort2*pv_comfort,
                     tau= list(tau_pv_comfort2_1, tau_pv_comfort2_2, tau_pv_comfort2_3, tau_pv_comfort2_4),
                     rows=pv_comfort2!=0)
  ol_settings10= list(outcomeOrdered= pv_economy1,
                     V= zeta_pv_economy1*pv_economy,
                     tau= list(tau_pv_economy1_1, tau_pv_economy1_2, tau_pv_economy1_3, tau_pv_economy1_4),
                     rows=pv_economy1!=0)
  ol_settings11= list(outcomeOrdered= pv_economy2,
                     V= zeta_pv_economy2*pv_economy,
                     tau= list(tau_pv_economy2_1, tau_pv_economy2_2, tau_pv_economy2_3, tau_pv_economy2_4),
                     rows=pv_economy2!=0)
  ol_settings12= list(outcomeOrdered= pv_economy3,
                     V= zeta_pv_economy3*pv_economy,
                     tau= list(tau_pv_economy3_1, tau_pv_economy3_2, tau_pv_economy3_3, tau_pv_economy3_4),
                     rows=pv_economy3!=0)
  ol_settings13= list(outcomeOrdered= pv_flexibility1,
                     V= zeta_pv_flexibility1*pv_flexibility,
                     tau= list(tau_pv_flexibility1_1, tau_pv_flexibility1_2),
                     rows=pv_flexibility1!=0)
  ol_settings14= list(outcomeOrdered= pv_flexibility2,
                     V= zeta_pv_flexibility2*pv_flexibility,
                     tau= list(tau_pv_flexibility2_1, tau_pv_flexibility2_2, tau_pv_flexibility2_3, tau_pv_flexibility2_4),
                     rows=pv_flexibility2!=0)
  ol_settings15= list(outcomeOrdered= pv_flexibility3,
                     V= zeta_pv_flexibility3*pv_flexibility,
                     tau= list(tau_pv_flexibility3_1, tau_pv_flexibility3_2, tau_pv_flexibility3_3, tau_pv_flexibility3_4),
                     rows=pv_flexibility3!=0)
  ol_settings16= list(outcomeOrdered= pt_comfort1,
                     V= zeta_pt_comfort1*pt_comfort,
                     tau= list(tau_pt_comfort1_1, tau_pt_comfort1_2, tau_pt_comfort1_3, tau_pt_comfort1_4),
                     rows=pt_comfort1!=0)
  ol_settings17= list(outcomeOrdered= pt_comfort2,
                     V= zeta_pt_comfort2*pt_comfort,
                     tau= list(tau_pt_comfort2_1, tau_pt_comfort2_2, tau_pt_comfort2_3, tau_pt_comfort2_4),
                     rows=pt_comfort2!=0)
  ol_settings18= list(outcomeOrdered= pt_comfort3,
                     V= zeta_pt_comfort3*pt_comfort,
                     tau= list(tau_pt_comfort3_1, tau_pt_comfort3_2, tau_pt_comfort3_3),
                     rows=pt_comfort3!=0)
  ol_settings43= list(outcomeOrdered= pt_comfort4,
                      V= zeta_pt_comfort4*pt_comfort,
                      tau= list(tau_pt_comfort4_1, tau_pt_comfort4_2, tau_pt_comfort4_3, tau_pt_comfort4_4),
                      rows=pt_comfort4!=0)
  ol_settings19= list(outcomeOrdered= pt_convenience1,
                     V= zeta_pt_convenience1*pt_convenience,
                     tau= list(tau_pt_convenience1_1, tau_pt_convenience1_2, tau_pt_convenience1_3, tau_pt_convenience1_4),
                     rows=pt_convenience1!=0)
  ol_settings20= list(outcomeOrdered= pt_convenience2,
                     V= zeta_pt_convenience2*pt_convenience,
                     tau= list(tau_pt_convenience2_1, tau_pt_convenience2_2, tau_pt_convenience2_3, tau_pt_convenience2_4),
                     rows=pt_convenience2!=0)
  ol_settings21= list(outcomeOrdered= pt_convenience3,
                     V= zeta_pt_convenience3*pt_convenience,
                     tau= list(tau_pt_convenience3_1, tau_pt_convenience3_2, tau_pt_convenience3_3, tau_pt_convenience3_4),
                     rows=pt_convenience3!=0)
  ol_settings22= list(outcomeOrdered= pt_safety1,
                     V= zeta_pt_safety1*pt_safety,
                     tau= list(tau_pt_safety1_1, tau_pt_safety1_2, tau_pt_safety1_3, tau_pt_safety1_4),
                     rows=pt_safety1!=0)
  ol_settings23= list(outcomeOrdered= pt_safety2,
                     V= zeta_pt_safety2*pt_safety,
                     tau= list(tau_pt_safety2_1, tau_pt_safety2_2, tau_pt_safety2_3, tau_pt_safety2_4),
                     rows=pt_safety2!=0)
  ol_settings24= list(outcomeOrdered= pt_safety3,
                     V= zeta_pt_safety3*pt_safety,
                     tau= list(tau_pt_safety3_1, tau_pt_safety3_2, tau_pt_safety3_3, tau_pt_safety3_4),
                     rows=pt_safety3!=0)
  ol_settings25= list(outcomeOrdered= pt_flexibility1,
                     V= zeta_pt_flexibility1*pt_flexibility,
                     tau= list(tau_pt_flexibility1_1, tau_pt_flexibility1_2, tau_pt_flexibility1_3, tau_pt_flexibility1_4),
                     rows=pt_flexibility1!=0)
  ol_settings26= list(outcomeOrdered= pt_flexibility2,
                     V= zeta_pt_flexibility2*pt_flexibility,
                     tau= list(tau_pt_flexibility2_1, tau_pt_flexibility2_2, tau_pt_flexibility2_3, tau_pt_flexibility2_4),
                     rows=pt_flexibility2!=0)
  ol_settings27= list(outcomeOrdered= pt_flexibility3,
                     V= zeta_pt_flexibility3*pt_flexibility,
                     tau= list(tau_pt_flexibility3_1, tau_pt_flexibility3_2, tau_pt_flexibility3_3, tau_pt_flexibility3_4),
                     rows=pt_flexibility3!=0)
  ol_settings28= list(outcomeOrdered= nmt_health1,
                     V= zeta_nmt_health1*nmt_health,
                     tau= list(tau_nmt_health1_1, tau_nmt_health1_2, tau_nmt_health1_3),
                     rows=nmt_health1!=0)
  ol_settings29= list(outcomeOrdered= nmt_health2,
                     V= zeta_nmt_health2*nmt_health,
                     tau= list(tau_nmt_health2_1, tau_nmt_health2_2, tau_nmt_health2_3, tau_nmt_health2_4),
                     rows=nmt_health2!=0)
  ol_settings30= list(outcomeOrdered= nmt_health3,
                     V= zeta_nmt_health3*nmt_health,
                     tau= list(tau_nmt_health3_1, tau_nmt_health3_2, tau_nmt_health3_3, tau_nmt_health3_4),
                     rows=nmt_health3!=0)
  ol_settings31= list(outcomeOrdered= nmt_safety1,
                     V= zeta_nmt_safety1*nmt_safety,
                     tau= list(tau_nmt_safety1_1, tau_nmt_safety1_2),
                     rows=nmt_safety1!=0)
  ol_settings32= list(outcomeOrdered= nmt_safety2,
                     V= zeta_nmt_safety2*nmt_safety,
                     tau= list(tau_nmt_safety2_1, tau_nmt_safety2_2, tau_nmt_safety2_3),
                     rows=nmt_safety2!=0)
  ol_settings33= list(outcomeOrdered= nmt_safety3,
                     V= zeta_nmt_safety3*nmt_safety,
                     tau= list(tau_nmt_safety3_1, tau_nmt_safety3_2, tau_nmt_safety3_3),
                     rows=nmt_safety3!=0)
  ol_settings34= list(outcomeOrdered= nmt_comfort1,
                     V= zeta_nmt_comfort1*nmt_comfort,
                     tau= list(tau_nmt_comfort1_1, tau_nmt_comfort1_2, tau_nmt_comfort1_3),
                     rows=nmt_comfort1!=0)
  ol_settings35= list(outcomeOrdered= nmt_comfort2,
                     V= zeta_nmt_comfort2*nmt_comfort,
                     tau= list(tau_nmt_comfort2_1, tau_nmt_comfort2_2, tau_nmt_comfort2_3),
                     rows=nmt_comfort2!=0)
  ol_settings36= list(outcomeOrdered= nmt_convenience1,
                     V= zeta_nmt_convenience1*nmt_convenience,
                     tau= list(tau_nmt_convenience1_1, tau_nmt_convenience1_2, tau_nmt_convenience1_3),
                     rows=nmt_convenience1!=0)
  ol_settings37= list(outcomeOrdered= nmt_convenience2,
                     V= zeta_nmt_convenience2*nmt_convenience,
                     tau= list(tau_nmt_convenience2_1, tau_nmt_convenience2_2),
                     rows=nmt_convenience2!=0)
  ol_settings38= list(outcomeOrdered= park_safety1,
                     V= zeta_park_safety1*park_safety,
                     tau= list(tau_park_safety1_1, tau_park_safety1_2, tau_park_safety1_3, tau_park_safety1_4),
                     rows=park_safety1!=0)
  ol_settings39= list(outcomeOrdered= park_safety2,
                     V= zeta_park_safety2*park_safety,
                     tau= list(tau_park_safety2_1, tau_park_safety2_2, tau_park_safety2_3),
                     rows=park_safety2!=0)
  ol_settings40= list(outcomeOrdered= park_convenience1,
                     V= zeta_park_convenience1*park_convenience,
                     tau= list(tau_park_convenience1_1, tau_park_convenience1_2, tau_park_convenience1_3, tau_park_convenience1_4),
                     rows=park_convenience1!=0)
  ol_settings41= list(outcomeOrdered= park_convenience2,
                     V= zeta_park_convenience2*park_convenience,
                     tau= list(tau_park_convenience2_1, tau_park_convenience2_2, tau_park_convenience2_3),
                     rows=park_convenience2!=0)
  ol_settings42= list(outcomeOrdered= park_convenience3,
                     V= zeta_park_convenience3*park_convenience,
                     tau= list(tau_park_convenience3_1, tau_park_convenience3_2, tau_park_convenience3_3, tau_park_convenience3_4),
                     rows=park_convenience3!=0)
  
  P[["indic_pv_individualist1"]]= apollo_ol(ol_settings1, functionality)
  P[["indic_pv_individualist2"]]= apollo_ol(ol_settings2, functionality)
  P[["indic_pv_individualist3"]]= apollo_ol(ol_settings3, functionality)
  P[["indic_pv_individualist4"]]= apollo_ol(ol_settings4, functionality)
  P[["indic_pv_proenv1"]]= apollo_ol(ol_settings5, functionality)
  P[["indic_pv_proenv2"]]= apollo_ol(ol_settings6, functionality)
  P[["indic_pv_proenv3"]]= apollo_ol(ol_settings7, functionality)
  P[["indic_pv_comfort1"]]= apollo_ol(ol_settings8, functionality)
  P[["indic_pv_comfort2"]]= apollo_ol(ol_settings9, functionality)
  P[["indic_pv_economy1"]]= apollo_ol(ol_settings10, functionality)
  P[["indic_pv_economy2"]]= apollo_ol(ol_settings11, functionality)
  P[["indic_pv_economy3"]]= apollo_ol(ol_settings12, functionality)
  P[["indic_pv_flexibility1"]]= apollo_ol(ol_settings13, functionality)
  P[["indic_pv_flexibility2"]]= apollo_ol(ol_settings14, functionality)
  P[["indic_pv_flexibility3"]]= apollo_ol(ol_settings15, functionality)
  P[["indic_pt_comfort1"]]= apollo_ol(ol_settings16, functionality)
  P[["indic_pt_comfort2"]]= apollo_ol(ol_settings17, functionality)
  P[["indic_pt_comfort3"]]= apollo_ol(ol_settings18, functionality)
  P[["indic_pt_comfort4"]]= apollo_ol(ol_settings43, functionality)
  P[["indic_pt_convenience1"]]= apollo_ol(ol_settings19, functionality)
  P[["indic_pt_convenience2"]]= apollo_ol(ol_settings20, functionality)
  P[["indic_pt_convenience3"]]= apollo_ol(ol_settings21, functionality)
  P[["indic_pt_safety1"]]= apollo_ol(ol_settings22, functionality)
  P[["indic_pt_safety2"]]= apollo_ol(ol_settings23, functionality)
  P[["indic_pt_safety3"]]= apollo_ol(ol_settings24, functionality)
  P[["indic_pt_flexibility1"]]= apollo_ol(ol_settings25, functionality)
  P[["indic_pt_flexibility2"]]= apollo_ol(ol_settings26, functionality)
  P[["indic_pt_flexibility3"]]= apollo_ol(ol_settings27, functionality)
  P[["indic_nmt_health1"]]= apollo_ol(ol_settings28, functionality)
  P[["indic_nmt_health2"]]= apollo_ol(ol_settings29, functionality)
  P[["indic_nmt_health3"]]= apollo_ol(ol_settings30, functionality)
  P[["indic_nmt_safety1"]]= apollo_ol(ol_settings31, functionality)
  P[["indic_nmt_safety2"]]= apollo_ol(ol_settings32, functionality)
  P[["indic_nmt_safety3"]]= apollo_ol(ol_settings33, functionality)
  P[["indic_nmt_comfort1"]]= apollo_ol(ol_settings34, functionality)
  P[["indic_nmt_comfort2"]]= apollo_ol(ol_settings35, functionality)
  P[["indic_nmt_convenience1"]]= apollo_ol(ol_settings36, functionality)
  P[["indic_nmt_convenience2"]]= apollo_ol(ol_settings37, functionality)
  P[["indic_park_safety1"]]= apollo_ol(ol_settings38, functionality)
  P[["indic_park_safety2"]]= apollo_ol(ol_settings39, functionality)
  P[["indic_park_convenience1"]]= apollo_ol(ol_settings40, functionality)
  P[["indic_park_convenience2"]]= apollo_ol(ol_settings41, functionality)
  P[["indic_park_convenience3"]]= apollo_ol(ol_settings42, functionality)
  
  ## Likelihood of the whole combined model
  
  P= apollo_combineModels(P, apollo_inputs, functionality)
  
  ## Prepare and return the outputs of the function
  
  P= apollo_prepareProb(P, apollo_inputs, functionality)
  
  return(P)
}

#L <- apollo_probabilities(apollo_beta, apollo_inputs, 'estimate')
## Model Estimation

# Likelihood before model estimation

#apollo_llCalc(apollo_beta, apollo_probabilities, apollo_inputs)

# Estimate Model

model = apollo_estimate(apollo_beta, apollo_fixed, apollo_probabilities, apollo_inputs)

## Model Output

apollo_modelOutput(model)

apollo_saveOutput(model)